@@ -312,8 +312,7 @@ Works on both Emacs and XEmacs."
 (defun org-in-invisibility-spec-p (arg)
   "Is ARG a member of `buffer-invisibility-spec'?"
   (if (consp buffer-invisibility-spec)
-      (member arg buffer-invisibility-spec)
-    nil))
+      (member arg buffer-invisibility-spec)))
 
 (defmacro org-xemacs-without-invisibility (&rest body)
   "Turn off extents with invisibility while executing BODY."
@@ -347,18 +346,8 @@ Works on both Emacs and XEmacs."
   "Move to column COLUMN.
 Pass COLUMN and FORCE to `move-to-column'.
 Pass BUFFER to the XEmacs version of `move-to-column'."
-  (let* ((with-bracket-link
-	  (save-excursion
-	    (forward-line 0)
-	    (looking-at (concat "^.*" org-bracket-link-regexp))))
-	 (buffer-invisibility-spec
-	  (cond
-	   ((or (not (derived-mode-p 'org-mode))
-		(and with-bracket-link (org-invisible-p2)))
-	    (remove '(org-link) buffer-invisibility-spec))
-	   (with-bracket-link
-	    (remove t buffer-invisibility-spec))
-	   (t buffer-invisibility-spec))))
+  (let ((buffer-invisibility-spec
+	 (remove '(org-filtered) buffer-invisibility-spec)))
     (if (featurep 'xemacs)
 	(org-xemacs-without-invisibility
 	 (move-to-column column force buffer))
